==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GridActiveCellChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridCellPositionDescriptionMetadata } from "./GridCellPositionDescriptionMetadata";
import { GridActiveCellChangedEventArgsDescription } from "./GridActiveCellChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridActiveCellChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridActiveCellChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridActiveCellChangedEventArgsDescriptionMetadata.a == null) {
                GridActiveCellChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridActiveCellChangedEventArgsDescriptionMetadata.c(GridActiveCellChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridActiveCellChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(GridActiveCellChangedEventArgsDescriptionMetadata.a);
            GridCellPositionDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("NewActiveCell", "ExportedType:GridCellPosition");
            a.item("OldActiveCell", "ExportedType:GridCellPosition");
        }
        static d(a) {
            GridActiveCellChangedEventArgsDescriptionMetadata.b(a);
            a.ad("GridActiveCellChangedEventArgs", () => new GridActiveCellChangedEventArgsDescription());
            a.ac("GridActiveCellChangedEventArgs", GridActiveCellChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridActiveCellChangedEventArgsDescriptionMetadata.$t = markType(GridActiveCellChangedEventArgsDescriptionMetadata, 'GridActiveCellChangedEventArgsDescriptionMetadata');
    GridActiveCellChangedEventArgsDescriptionMetadata.a = null;
    return GridActiveCellChangedEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GridActiveCellChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridCellPositionDescriptionMetadata } from "./GridCellPositionDescriptionMetadata";
import { GridActiveCellChangedEventArgsDescription } from "./GridActiveCellChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridActiveCellChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridActiveCellChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridActiveCellChangedEventArgsDescriptionMetadata.a == null) {
                GridActiveCellChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridActiveCellChangedEventArgsDescriptionMetadata.c(GridActiveCellChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridActiveCellChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridActiveCellChangedEventArgsDescriptionMetadata.a);
            GridCellPositionDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("NewActiveCell", "ExportedType:GridCellPosition");
            a.item("OldActiveCell", "ExportedType:GridCellPosition");
        }
        static d(a) {
            GridActiveCellChangedEventArgsDescriptionMetadata.b(a);
            a.ae("GridActiveCellChangedEventArgs", () => new GridActiveCellChangedEventArgsDescription());
            a.ad("GridActiveCellChangedEventArgs", GridActiveCellChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridActiveCellChangedEventArgsDescriptionMetadata.$t = markType(GridActiveCellChangedEventArgsDescriptionMetadata, 'GridActiveCellChangedEventArgsDescriptionMetadata');
    GridActiveCellChangedEventArgsDescriptionMetadata.a = null;
    return GridActiveCellChangedEventArgsDescriptionMetadata;
})();
